#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-hedgehog
version:              0.1.0.0
visibility:           public
id:                   hspec-hedgehog-0.1.0.0-6VkWdPYOqGW1wEwd8GWceu
key:                  hspec-hedgehog-0.1.0.0-6VkWdPYOqGW1wEwd8GWceu
license:              BSD-3-Clause
copyright:            2020 Matt Parsons
maintainer:           parsonsmatt@gmail.com
author:               Matt Parsons
homepage:             https://github.com/parsonsmatt/hspec-hedgehog#readme
synopsis:             Integrate Hedgehog and Hspec!
description:
    Please see the README on GitHub at <https://github.com/parsonsmatt/hspec-hedgehog#readme>

category:             Testing
abi:                  f0da76fe9ebae3ebf453c618fe405322
exposed:              True
exposed-modules:      Test.Hspec.Hedgehog
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hspec-hedgehog-0.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hspec-hedgehog-0.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hspec-hedgehog-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-hedgehog
hs-libraries:         HShspec-hedgehog-0.1.0.0-6VkWdPYOqGW1wEwd8GWceu
depends:
    QuickCheck-2.15.0.1-Ger2uBePW3nE0joHfQHA2C base-4.18.2.1
    hedgehog-1.5-Ju5SKj5jFqYDjuBa0MBjPF
    hspec-2.11.7-1Z0PDyf0enY3NJ1rrLm1pA
    hspec-core-2.11.7-C9vX6niVxxjKtO8zyfnbpo
    splitmix-0.1.3.1-2MYKaPhjqX94pT896ZTXWn

haddock-interfaces:
    /usr/share/doc/haskell-hspec-hedgehog/html/hspec-hedgehog.haddock

haddock-html:         /usr/share/doc/haskell-hspec-hedgehog/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

